@@ -3,10 +3,10 @@
 # A small script to help run example apps
 #
 
-prefix=/home/jeff/install
+prefix=/home/jeff/gnome
 exec_prefix=${prefix}
 libdir=${exec_prefix}/lib
-classpath=${prefix}/share/java/gconf2.10-2.10.0.jar
+classpath=${prefix}/share/java/gconf2.11-2.11.2.jar
 
 GCONFJAVA_LIB=$libdir
 GCONFJAVA_JAR=$classpath
