@@ -9,12 +9,12 @@
 
 package org.gnu.gconf;
 
-import org.gnu.glib.Boxed;
-import org.gnu.glib.Handle;
+import org.gnu.javagnome.Handle;
+import org.gnu.javagnome.Struct;
 
 /**
  */
-public class ConfSchema extends Boxed {
+public class ConfSchema extends Struct {
 	
 	public ConfSchema() {
 		super(gconf_schema_new());
@@ -29,84 +29,84 @@ public class ConfSchema extends Boxed {
 	 */
 	protected void finalize() throws Throwable {
 		super.finalize();
-		gconf_schema_free(handle);
+		gconf_schema_free(getHandle());
 	}
 	
 	public String getLocale() {
-		return gconf_schema_get_locale(handle);
+		return gconf_schema_get_locale(getHandle());
 	}
 	
 	public void setLocale(String locale) {
-		gconf_schema_set_locale(handle, locale);
+		gconf_schema_set_locale(getHandle(), locale);
 	}
 	
 	public String getShortDescription() {
-		return gconf_schema_get_short_desc(handle);
+		return gconf_schema_get_short_desc(getHandle());
 	}
 	
 	public void setShortDescription(String desc) {
-		gconf_schema_set_short_desc(handle, desc);
+		gconf_schema_set_short_desc(getHandle(), desc);
 	}
 	
 	public String getLongDescription() {
-		return gconf_schema_get_long_desc(handle);
+		return gconf_schema_get_long_desc(getHandle());
 	}
 	
 	public void setLongDescription(String desc) {
-		gconf_schema_set_long_desc(handle, desc);
+		gconf_schema_set_long_desc(getHandle(), desc);
 	}
 	
 	public String getOwner() {
-		return gconf_schema_get_owner(handle);
+		return gconf_schema_get_owner(getHandle());
 	}
 	
 	public void setOwner(String owner) {
-		gconf_schema_set_owner(handle, owner);
+		gconf_schema_set_owner(getHandle(), owner);
 	}
 	
 	public ConfValueType getType() {
-		int hndl = gconf_schema_get_type(handle);
+		int hndl = gconf_schema_get_type(getHandle());
 		return ConfValueType.intern(hndl);
 	}
 	
 	public void setType(ConfValueType type) {
-		gconf_schema_set_type(handle, type.getValue());
+		gconf_schema_set_type(getHandle(), type.getValue());
 	}
 	
 	public ConfValueType getListType() {
-		int hndl = gconf_schema_get_list_type(handle);
+		int hndl = gconf_schema_get_list_type(getHandle());
 		return ConfValueType.intern(hndl);
 	}
 	
 	public void setListType(ConfValueType type) {
-		gconf_schema_set_list_type(handle, type.getValue());
+		gconf_schema_set_list_type(getHandle(), type.getValue());
 	}
 	
 	public ConfValueType getCarType() {
-		int hndl = gconf_schema_get_car_type(handle);
+		int hndl = gconf_schema_get_car_type(getHandle());
 		return ConfValueType.intern(hndl);
 	}
 	
 	public void setCarType(ConfValueType type) {
-		gconf_schema_set_car_type(handle, type.getValue());
+		gconf_schema_set_car_type(getHandle(), type.getValue());
 	}
 	
 	public ConfValueType getCdrType() {
-		int hndl = gconf_schema_get_cdr_type(handle);
+		int hndl = gconf_schema_get_cdr_type(getHandle());
 		return ConfValueType.intern(hndl);
 	}
 	
 	public void setCdrType(ConfValueType type) {
-		gconf_schema_set_cdr_type(handle, type.getValue());
+		gconf_schema_set_cdr_type(getHandle(), type.getValue());
 	}
 
 	public ConfValue getDefaultValue() {
-		Handle hndl = gconf_schema_get_default_value(handle);
+		Handle hndl = gconf_schema_get_default_value(getHandle());
 		return new ConfValue(hndl);
 	}
 	
 	public void setDefaultValue(ConfValue value) {
-		gconf_schema_set_default_value(handle, value.getHandle());
+		gconf_schema_set_default_value(getHandle(), value.getHandle());
 	}
 	
 
